@@ -1,13 +1,18 @@
+#ifndef QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+#define QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+
 #define QT_FEATURE_webengine_embedded_build -1
 
 #define QT_FEATURE_webengine_system_alsa 1
 
 #define QT_FEATURE_webengine_v8_context_snapshot 1
 
-#define QT_FEATURE_webengine_system_pulseaudio 1
+#define QT_FEATURE_webengine_system_pulseaudio -1
 
 #define QT_FEATURE_webengine_system_gbm 1
 
+#define QT_FEATURE_webengine_webrtc_system_openh264 -1
+
 #define QT_FEATURE_webengine_printing_and_pdf 1
 
 #define QT_FEATURE_webengine_pepper_plugins 1
@@ -30,3 +35,5 @@
 
 #define QT_FEATURE_webengine_arm64_udot_support -1
 
+
+#endif // QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
