@@ -1,7 +1,7 @@
 #ifndef QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_h_H
 #define QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_h_H
 
-#define QT_FEATURE_webengine_geolocation 1
+#define QT_FEATURE_webengine_geolocation -1
 
 #define QT_FEATURE_webengine_webchannel 1
 
